@@ -2,7 +2,7 @@ import sys
 from importlib import import_module
 
 
-def safe_import(module: str, silence: bool = False, reraise: bool = False):
+def safe_import(module: str, silence: bool = True, reraise: bool = False):
     try:
         return import_module(module)
     except ImportError as e:
